==> dropwizard-revolver-1.3.7-23-20190327.013222-2-sources.jar: io/dropwizard/revolver/retry/RetryUtils.java <==
package io.dropwizard.revolver.retry;

import com.github.rholder.retry.Retryer;
import com.github.rholder.retry.RetryerBuilder;
import com.github.rholder.retry.StopStrategies;
import com.github.rholder.retry.WaitStrategies;
import io.dropwizard.revolver.http.config.RevolverHttpApiConfig;

import java.util.concurrent.TimeUnit;

/***
 Created by nitish.goyal on 25/02/19
 ***/
public class RetryUtils {

    private static final int MIN_ATTEMPT = 2;
    private static final int MIN_WAIT_IN_SECS = 3;

    private static final Retryer<Boolean> DEFAULT_RETRYER = RetryerBuilder.<Boolean>newBuilder().retryIfException()
            .withStopStrategy(StopStrategies.stopAfterAttempt(MIN_ATTEMPT))
            .withWaitStrategy(WaitStrategies.fixedWait(MIN_WAIT_IN_SECS, TimeUnit.SECONDS))
            .build();

    private static final long INITIAL_WAIT_IN_MILLS = 200;

    public static Retryer getDefaultRetryer(){
        return RetryerBuilder.newBuilder()
                .retryIfResult(new ValidResponseFilter())
                .withStopStrategy(StopStrategies.stopAfterAttempt(RevolverApiRetryConfig.MAX_RETRY))
                .withWaitStrategy(WaitStrategies.fixedWait(RevolverApiRetryConfig.MAXIMUM_WAIT_TIME_IN_SECONDS, TimeUnit.SECONDS))
                .build();
    }

    public static Retryer getRetryer(RevolverHttpApiConfig revolverHttpApiConfig) {

        RevolverApiRetryConfig revolverApiRetryConfig = revolverHttpApiConfig.getRetryConfig();
        int maximumTimeInSeconds = revolverHttpApiConfig.getRetryConfig()
                .getMaximumTimeInSeconds();
        if(maximumTimeInSeconds == 0) {
            maximumTimeInSeconds = RevolverApiRetryConfig.MAXIMUM_WAIT_TIME_IN_SECONDS;
        }

        int maxRetry = revolverApiRetryConfig.getMaxRetry();
        if(maxRetry == 0) {
            maxRetry = RevolverApiRetryConfig.MAX_RETRY;
        }

        long incrementByInMillis = revolverApiRetryConfig.getIncrementByInMillis();
        if(incrementByInMillis == 0) {
            incrementByInMillis = RevolverApiRetryConfig.INCREMENT_BY_IN_MILLIS;
        }

        WaitStrategy waitStrategy = revolverApiRetryConfig.getWaitStrategy();
        if(waitStrategy == null) {
            waitStrategy = WaitStrategy.EXPONENTIAL;
        }

        switch (waitStrategy) {
            case FIXED:
                return RetryerBuilder.newBuilder()
                        .retryIfResult(new ValidResponseFilter())
                        .withStopStrategy(StopStrategies.stopAfterAttempt(maxRetry))
                        .withWaitStrategy(WaitStrategies.fixedWait(maximumTimeInSeconds, TimeUnit.SECONDS))
                        .build();

            case NO_WAIT:
                return RetryerBuilder.newBuilder()
                        .retryIfResult(new ValidResponseFilter())
                        .withStopStrategy(StopStrategies.stopAfterAttempt(maxRetry))
                        .withWaitStrategy(WaitStrategies.noWait())
                        .build();

            case EXPONENTIAL:
                return RetryerBuilder.newBuilder()
                        .retryIfResult(new ValidResponseFilter())
                        .withStopStrategy(StopStrategies.stopAfterAttempt(maxRetry))
                        .withWaitStrategy(WaitStrategies.exponentialWait(maximumTimeInSeconds, TimeUnit.SECONDS))
                        .build();

            case INCREMENTAL:
                return RetryerBuilder.newBuilder()
                        .retryIfResult(new ValidResponseFilter())
                        .withStopStrategy(StopStrategies.stopAfterAttempt(maxRetry))
                        .withWaitStrategy(WaitStrategies.incrementingWait(INITIAL_WAIT_IN_MILLS, TimeUnit.MILLISECONDS, incrementByInMillis,
                                                                          TimeUnit.MILLISECONDS
                                                                         ))
                        .build();

            case FIBONACCI:
                return RetryerBuilder.newBuilder()
                        .retryIfResult(new ValidResponseFilter())
                        .withStopStrategy(StopStrategies.stopAfterAttempt(maxRetry))
                        .withWaitStrategy(WaitStrategies.fibonacciWait(maximumTimeInSeconds, TimeUnit.SECONDS))
                        .build();
        }
        return DEFAULT_RETRYER;

    }
}

==> dropwizard-revolver-1.3.7-24-20190327.112620-1-sources.jar: io/dropwizard/revolver/retry/RetryUtils.java <==
package io.dropwizard.revolver.retry;

import com.github.rholder.retry.Retryer;
import com.github.rholder.retry.RetryerBuilder;
import com.github.rholder.retry.StopStrategies;
import com.github.rholder.retry.WaitStrategies;
import io.dropwizard.revolver.http.config.RevolverHttpApiConfig;

import java.util.concurrent.TimeUnit;

/***
 Created by nitish.goyal on 25/02/19
 ***/
public class RetryUtils {

    private static final long INITIAL_WAIT_IN_MILLS = 200;

    public static <T> Retryer<T> getRetryer(RevolverHttpApiConfig revolverHttpApiConfig) {

        RevolverApiRetryConfig revolverApiRetryConfig = revolverHttpApiConfig.getRetryConfig();
        int maximumTimeInSeconds = revolverHttpApiConfig.getRetryConfig()
                .getMaximumTimeInSeconds();
        if(maximumTimeInSeconds == 0) {
            maximumTimeInSeconds = RevolverApiRetryConfig.MAXIMUM_WAIT_TIME_IN_SECONDS;
        }

        int maxRetry = revolverApiRetryConfig.getMaxRetry();
        if(maxRetry == 0) {
            maxRetry = RevolverApiRetryConfig.MAX_RETRY;
        }

        long incrementByInMillis = revolverApiRetryConfig.getIncrementByInMillis();
        if(incrementByInMillis == 0) {
            incrementByInMillis = RevolverApiRetryConfig.INCREMENT_BY_IN_MILLIS;
        }

        WaitStrategy waitStrategy = revolverApiRetryConfig.getWaitStrategy();
        if(waitStrategy == null) {
            waitStrategy = WaitStrategy.EXPONENTIAL;
        }

        switch (waitStrategy) {
            case FIXED:
                return RetryerBuilder.<T>newBuilder()
                        .retryIfResult(new ValidResponseFilter<>())
                        .withStopStrategy(StopStrategies.stopAfterAttempt(maxRetry))
                        .withWaitStrategy(WaitStrategies.fixedWait(maximumTimeInSeconds, TimeUnit.SECONDS))
                        .build();

            case NO_WAIT:
                return RetryerBuilder.<T>newBuilder()
                        .retryIfResult(new ValidResponseFilter<>())
                        .withStopStrategy(StopStrategies.stopAfterAttempt(maxRetry))
                        .withWaitStrategy(WaitStrategies.noWait())
                        .build();

            case EXPONENTIAL:
                return RetryerBuilder.<T>newBuilder()
                        .retryIfResult(new ValidResponseFilter<>())
                        .withStopStrategy(StopStrategies.stopAfterAttempt(maxRetry))
                        .withWaitStrategy(WaitStrategies.exponentialWait(maximumTimeInSeconds, TimeUnit.SECONDS))
                        .build();

            case INCREMENTAL:
                return RetryerBuilder.<T>newBuilder()
                        .retryIfResult(new ValidResponseFilter<>())
                        .withStopStrategy(StopStrategies.stopAfterAttempt(maxRetry))
                        .withWaitStrategy(WaitStrategies.incrementingWait(INITIAL_WAIT_IN_MILLS, TimeUnit.MILLISECONDS, incrementByInMillis,
                                                                          TimeUnit.MILLISECONDS
                                                                         ))
                        .build();

            case FIBONACCI:
                return RetryerBuilder.<T>newBuilder()
                        .retryIfResult(new ValidResponseFilter<>())
                        .withStopStrategy(StopStrategies.stopAfterAttempt(maxRetry))
                        .withWaitStrategy(WaitStrategies.fibonacciWait(maximumTimeInSeconds, TimeUnit.SECONDS))
                        .build();
        }
        return RetryerBuilder.<T>newBuilder().retryIfException()
                .withStopStrategy(StopStrategies.stopAfterAttempt(RevolverApiRetryConfig.MAX_RETRY))
                .withWaitStrategy(WaitStrategies.exponentialWait(RevolverApiRetryConfig.MAXIMUM_WAIT_TIME_IN_SECONDS, TimeUnit.SECONDS))
                .build();

    }
}
